# This File GEN using nerdicons_gen.py

class Weather:

	# CHAR : 
	weather_alien = "\ue36e"
	# CHAR : 
	weather_aliens = "\ue345"
	# CHAR : 
	weather_barometer = "\ue372"
	# CHAR : 
	weather_celsius = "\ue339"
	# CHAR : 
	weather_cloud = "\ue33d"
	# CHAR : 
	weather_cloud_down = "\ue33a"
	# CHAR : 
	weather_cloud_refresh = "\ue33b"
	# CHAR : 
	weather_cloud_up = "\ue33c"
	# CHAR : 
	weather_cloudy = "\ue312"
	# CHAR : 
	weather_cloudy_gusts = "\ue310"
	# CHAR : 
	weather_cloudy_windy = "\ue311"
	# CHAR : 
	weather_day_cloudy = "\ue302"
	# CHAR : 
	weather_day_cloudy_gusts = "\ue300"
	# CHAR : 
	weather_day_cloudy_high = "\ue376"
	# CHAR : 
	weather_day_cloudy_windy = "\ue301"
	# CHAR : 
	weather_day_fog = "\ue303"
	# CHAR : 
	weather_day_hail = "\ue304"
	# CHAR : 
	weather_day_haze = "\ue3ae"
	# CHAR : 
	weather_day_light_wind = "\ue3bc"
	# CHAR : 
	weather_day_lightning = "\ue305"
	# CHAR : 
	weather_day_rain = "\ue308"
	# CHAR : 
	weather_day_rain_mix = "\ue306"
	# CHAR : 
	weather_day_rain_wind = "\ue307"
	# CHAR : 
	weather_day_showers = "\ue309"
	# CHAR : 
	weather_day_sleet = "\ue3aa"
	# CHAR : 
	weather_day_sleet_storm = "\ue362"
	# CHAR : 
	weather_day_snow = "\ue30a"
	# CHAR : 
	weather_day_snow_thunderstorm = "\ue365"
	# CHAR : 
	weather_day_snow_wind = "\ue35f"
	# CHAR : 
	weather_day_sprinkle = "\ue30b"
	# CHAR : 
	weather_day_storm_showers = "\ue30e"
	# CHAR : 
	weather_day_sunny = "\ue30d"
	# CHAR : 
	weather_day_sunny_overcast = "\ue30c"
	# CHAR : 
	weather_day_thunderstorm = "\ue30f"
	# CHAR : 
	weather_day_windy = "\ue37d"
	# CHAR : 
	weather_degrees = "\ue33e"
	# CHAR : 
	weather_direction_down = "\ue340"
	# CHAR : 
	weather_direction_down_left = "\ue33f"
	# CHAR : 
	weather_direction_down_right = "\ue380"
	# CHAR : 
	weather_direction_left = "\ue344"
	# CHAR : 
	weather_direction_right = "\ue349"
	# CHAR : 
	weather_direction_up = "\ue353"
	# CHAR : 
	weather_direction_up_left = "\ue37f"
	# CHAR : 
	weather_direction_up_right = "\ue352"
	# CHAR : 
	weather_dust = "\ue35d"
	# CHAR : 
	weather_earthquake = "\ue3be"
	# CHAR : 
	weather_fahrenheit = "\ue341"
	# CHAR : 
	weather_fire = "\ue3bf"
	# CHAR : 
	weather_flood = "\ue375"
	# CHAR : 
	weather_fog = "\ue313"
	# CHAR : 
	weather_gale_warning = "\ue3c5"
	# CHAR : 
	weather_hail = "\ue314"
	# CHAR : 
	weather_horizon = "\ue343"
	# CHAR : 
	weather_horizon_alt = "\ue342"
	# CHAR : 
	weather_hot = "\ue36b"
	# CHAR : 
	weather_humidity = "\ue373"
	# CHAR : 
	weather_hurricane = "\ue36c"
	# CHAR : 
	weather_hurricane_warning = "\ue3c7"
	# CHAR : 
	weather_lightning = "\ue315"
	# CHAR : 
	weather_lunar_eclipse = "\ue369"
	# CHAR : 
	weather_meteor = "\ue36a"
	# CHAR : 
	weather_moon_alt_first_quarter = "\ue3ce"
	# CHAR : 
	weather_moon_alt_full = "\ue3d5"
	# CHAR : 
	weather_moon_alt_new = "\ue3e3"
	# CHAR : 
	weather_moon_alt_third_quarter = "\ue3dc"
	# CHAR : 
	weather_moon_alt_waning_crescent_1 = "\ue3dd"
	# CHAR : 
	weather_moon_alt_waning_crescent_2 = "\ue3de"
	# CHAR : 
	weather_moon_alt_waning_crescent_3 = "\ue3df"
	# CHAR : 
	weather_moon_alt_waning_crescent_4 = "\ue3e0"
	# CHAR : 
	weather_moon_alt_waning_crescent_5 = "\ue3e1"
	# CHAR : 
	weather_moon_alt_waning_crescent_6 = "\ue3e2"
	# CHAR : 
	weather_moon_alt_waning_gibbous_1 = "\ue3d6"
	# CHAR : 
	weather_moon_alt_waning_gibbous_2 = "\ue3d7"
	# CHAR : 
	weather_moon_alt_waning_gibbous_3 = "\ue3d8"
	# CHAR : 
	weather_moon_alt_waning_gibbous_4 = "\ue3d9"
	# CHAR : 
	weather_moon_alt_waning_gibbous_5 = "\ue3da"
	# CHAR : 
	weather_moon_alt_waning_gibbous_6 = "\ue3db"
	# CHAR : 
	weather_moon_alt_waxing_crescent_1 = "\ue3c8"
	# CHAR : 
	weather_moon_alt_waxing_crescent_2 = "\ue3c9"
	# CHAR : 
	weather_moon_alt_waxing_crescent_3 = "\ue3ca"
	# CHAR : 
	weather_moon_alt_waxing_crescent_4 = "\ue3cb"
	# CHAR : 
	weather_moon_alt_waxing_crescent_5 = "\ue3cc"
	# CHAR : 
	weather_moon_alt_waxing_crescent_6 = "\ue3cd"
	# CHAR : 
	weather_moon_alt_waxing_gibbous_1 = "\ue3cf"
	# CHAR : 
	weather_moon_alt_waxing_gibbous_2 = "\ue3d0"
	# CHAR : 
	weather_moon_alt_waxing_gibbous_3 = "\ue3d1"
	# CHAR : 
	weather_moon_alt_waxing_gibbous_4 = "\ue3d2"
	# CHAR : 
	weather_moon_alt_waxing_gibbous_5 = "\ue3d3"
	# CHAR : 
	weather_moon_alt_waxing_gibbous_6 = "\ue3d4"
	# CHAR : 
	weather_moon_first_quarter = "\ue394"
	# CHAR : 
	weather_moon_full = "\ue39b"
	# CHAR : 
	weather_moon_new = "\ue38d"
	# CHAR : 
	weather_moon_third_quarter = "\ue3a2"
	# CHAR : 
	weather_moon_waning_crescent_1 = "\ue3a3"
	# CHAR : 
	weather_moon_waning_crescent_2 = "\ue3a4"
	# CHAR : 
	weather_moon_waning_crescent_3 = "\ue3a5"
	# CHAR : 
	weather_moon_waning_crescent_4 = "\ue3a6"
	# CHAR : 
	weather_moon_waning_crescent_5 = "\ue3a7"
	# CHAR : 
	weather_moon_waning_crescent_6 = "\ue3a8"
	# CHAR : 
	weather_moon_waning_gibbous_1 = "\ue39c"
	# CHAR : 
	weather_moon_waning_gibbous_2 = "\ue39d"
	# CHAR : 
	weather_moon_waning_gibbous_3 = "\ue39e"
	# CHAR : 
	weather_moon_waning_gibbous_4 = "\ue39f"
	# CHAR : 
	weather_moon_waning_gibbous_5 = "\ue3a0"
	# CHAR : 
	weather_moon_waning_gibbous_6 = "\ue3a1"
	# CHAR : 
	weather_moon_waxing_crescent_1 = "\ue38e"
	# CHAR : 
	weather_moon_waxing_crescent_2 = "\ue38f"
	# CHAR : 
	weather_moon_waxing_crescent_3 = "\ue390"
	# CHAR : 
	weather_moon_waxing_crescent_4 = "\ue391"
	# CHAR : 
	weather_moon_waxing_crescent_5 = "\ue392"
	# CHAR : 
	weather_moon_waxing_crescent_6 = "\ue393"
	# CHAR : 
	weather_moon_waxing_gibbous_1 = "\ue395"
	# CHAR : 
	weather_moon_waxing_gibbous_2 = "\ue396"
	# CHAR : 
	weather_moon_waxing_gibbous_3 = "\ue397"
	# CHAR : 
	weather_moon_waxing_gibbous_4 = "\ue398"
	# CHAR : 
	weather_moon_waxing_gibbous_5 = "\ue399"
	# CHAR : 
	weather_moon_waxing_gibbous_6 = "\ue39a"
	# CHAR : 
	weather_moonrise = "\ue3c1"
	# CHAR : 
	weather_moonset = "\ue3c2"
	# CHAR : 
	weather_na = "\ue374"
	# CHAR : 
	weather_night_alt_cloudy = "\ue37e"
	# CHAR : 
	weather_night_alt_cloudy_gusts = "\ue31f"
	# CHAR : 
	weather_night_alt_cloudy_high = "\ue377"
	# CHAR : 
	weather_night_alt_cloudy_windy = "\ue320"
	# CHAR : 
	weather_night_alt_hail = "\ue321"
	# CHAR : 
	weather_night_alt_lightning = "\ue322"
	# CHAR : 
	weather_night_alt_partly_cloudy = "\ue379"
	# CHAR : 
	weather_night_alt_rain = "\ue325"
	# CHAR : 
	weather_night_alt_rain_mix = "\ue323"
	# CHAR : 
	weather_night_alt_rain_wind = "\ue324"
	# CHAR : 
	weather_night_alt_showers = "\ue326"
	# CHAR : 
	weather_night_alt_sleet = "\ue3ac"
	# CHAR : 
	weather_night_alt_sleet_storm = "\ue364"
	# CHAR : 
	weather_night_alt_snow = "\ue327"
	# CHAR : 
	weather_night_alt_snow_thunderstorm = "\ue367"
	# CHAR : 
	weather_night_alt_snow_wind = "\ue361"
	# CHAR : 
	weather_night_alt_sprinkle = "\ue328"
	# CHAR : 
	weather_night_alt_storm_showers = "\ue329"
	# CHAR : 
	weather_night_alt_thunderstorm = "\ue32a"
	# CHAR : 
	weather_night_clear = "\ue32b"
	# CHAR : 
	weather_night_cloudy = "\ue32e"
	# CHAR : 
	weather_night_cloudy_gusts = "\ue32c"
	# CHAR : 
	weather_night_cloudy_high = "\ue378"
	# CHAR : 
	weather_night_cloudy_windy = "\ue32d"
	# CHAR : 
	weather_night_fog = "\ue346"
	# CHAR : 
	weather_night_hail = "\ue32f"
	# CHAR : 
	weather_night_lightning = "\ue330"
	# CHAR : 
	weather_night_partly_cloudy = "\ue37b"
	# CHAR : 
	weather_night_rain = "\ue333"
	# CHAR : 
	weather_night_rain_mix = "\ue331"
	# CHAR : 
	weather_night_rain_wind = "\ue332"
	# CHAR : 
	weather_night_showers = "\ue334"
	# CHAR : 
	weather_night_sleet = "\ue3ab"
	# CHAR : 
	weather_night_sleet_storm = "\ue363"
	# CHAR : 
	weather_night_snow = "\ue335"
	# CHAR : 
	weather_night_snow_thunderstorm = "\ue366"
	# CHAR : 
	weather_night_snow_wind = "\ue360"
	# CHAR : 
	weather_night_sprinkle = "\ue336"
	# CHAR : 
	weather_night_storm_showers = "\ue337"
	# CHAR : 
	weather_night_thunderstorm = "\ue338"
	# CHAR : 
	weather_rain = "\ue318"
	# CHAR : 
	weather_rain_mix = "\ue316"
	# CHAR : 
	weather_rain_wind = "\ue317"
	# CHAR : 
	weather_raindrop = "\ue371"
	# CHAR : 
	weather_raindrops = "\ue34a"
	# CHAR : 
	weather_refresh = "\ue348"
	# CHAR : 
	weather_refresh_alt = "\ue347"
	# CHAR : 
	weather_sandstorm = "\ue37a"
	# CHAR : 
	weather_showers = "\ue319"
	# CHAR : 
	weather_sleet = "\ue3ad"
	# CHAR : 
	weather_small_craft_advisory = "\ue3c4"
	# CHAR : 
	weather_smog = "\ue36d"
	# CHAR : 
	weather_smoke = "\ue35c"
	# CHAR : 
	weather_snow = "\ue31a"
	# CHAR : 
	weather_snow_wind = "\ue35e"
	# CHAR : 
	weather_snowflake_cold = "\ue36f"
	# CHAR : 
	weather_solar_eclipse = "\ue368"
	# CHAR : 
	weather_sprinkle = "\ue31b"
	# CHAR : 
	weather_stars = "\ue370"
	# CHAR : 
	weather_storm_showers = "\ue31c"
	# CHAR : 
	weather_storm_warning = "\ue3c6"
	# CHAR : 
	weather_strong_wind = "\ue34b"
	# CHAR : 
	weather_sunrise = "\ue34c"
	# CHAR : 
	weather_sunset = "\ue34d"
	# CHAR : 
	weather_thermometer = "\ue350"
	# CHAR : 
	weather_thermometer_exterior = "\ue34e"
	# CHAR : 
	weather_thermometer_internal = "\ue34f"
	# CHAR : 
	weather_thunderstorm = "\ue31d"
	# CHAR : 
	weather_time_1 = "\ue382"
	# CHAR : 
	weather_time_10 = "\ue38b"
	# CHAR : 
	weather_time_11 = "\ue38c"
	# CHAR : 
	weather_time_12 = "\ue381"
	# CHAR : 
	weather_time_2 = "\ue383"
	# CHAR : 
	weather_time_3 = "\ue384"
	# CHAR : 
	weather_time_4 = "\ue385"
	# CHAR : 
	weather_time_5 = "\ue386"
	# CHAR : 
	weather_time_6 = "\ue387"
	# CHAR : 
	weather_time_7 = "\ue388"
	# CHAR : 
	weather_time_8 = "\ue389"
	# CHAR : 
	weather_time_9 = "\ue38a"
	# CHAR : 
	weather_tornado = "\ue351"
	# CHAR : 
	weather_train = "\ue3c3"
	# CHAR : 
	weather_tsunami = "\ue3bd"
	# CHAR : 
	weather_umbrella = "\ue37c"
	# CHAR : 
	weather_volcano = "\ue3c0"
	# CHAR : 
	weather_wind_beaufort_0 = "\ue3af"
	# CHAR : 
	weather_wind_beaufort_1 = "\ue3b0"
	# CHAR : 
	weather_wind_beaufort_10 = "\ue3b9"
	# CHAR : 
	weather_wind_beaufort_11 = "\ue3ba"
	# CHAR : 
	weather_wind_beaufort_12 = "\ue3bb"
	# CHAR : 
	weather_wind_beaufort_2 = "\ue3b1"
	# CHAR : 
	weather_wind_beaufort_3 = "\ue3b2"
	# CHAR : 
	weather_wind_beaufort_4 = "\ue3b3"
	# CHAR : 
	weather_wind_beaufort_5 = "\ue3b4"
	# CHAR : 
	weather_wind_beaufort_6 = "\ue3b5"
	# CHAR : 
	weather_wind_beaufort_7 = "\ue3b6"
	# CHAR : 
	weather_wind_beaufort_8 = "\ue3b7"
	# CHAR : 
	weather_wind_beaufort_9 = "\ue3b8"
	# CHAR : 
	weather_wind_direction = "\ue3a9"
	# CHAR : 
	weather_wind_east = "\ue35b"
	# CHAR : 
	weather_wind_north = "\ue35a"
	# CHAR : 
	weather_wind_north_east = "\ue359"
	# CHAR : 
	weather_wind_north_west = "\ue358"
	# CHAR : 
	weather_wind_south = "\ue357"
	# CHAR : 
	weather_wind_south_east = "\ue356"
	# CHAR : 
	weather_wind_south_west = "\ue355"
	# CHAR : 
	weather_wind_west = "\ue354"
	# CHAR : 
	weather_windy = "\ue31e"


# This File GEN using nerdicons_gen.py

class Seti:

	# CHAR : 
	seti_apple = "\ue635"
	# CHAR : 
	seti_argdown = "\ue636"
	# CHAR : 
	seti_asm = "\ue637"
	# CHAR : 
	seti_audio = "\ue638"
	# CHAR : 
	seti_babel = "\ue639"
	# CHAR : 
	seti_bazel = "\ue63a"
	# CHAR : 
	seti_bicep = "\ue63b"
	# CHAR : 
	seti_bower = "\ue61a"
	# CHAR : 
	seti_bsl = "\ue63c"
	# CHAR : 
	seti_c = "\ue649"
	# CHAR : 
	seti_c_sharp = "\ue648"
	# CHAR : 
	seti_cake = "\ue63e"
	# CHAR : 
	seti_cake_php = "\ue63d"
	# CHAR : 
	seti_checkbox = "\ue63f"
	# CHAR : 
	seti_checkbox_unchecked = "\ue640"
	# CHAR : 
	seti_cjsx = "\ue61b"
	# CHAR : 
	seti_clock = "\ue641"
	# CHAR : 
	seti_clojure = "\ue642"
	# CHAR : 
	seti_code_climate = "\ue643"
	# CHAR : 
	seti_code_search = "\ue644"
	# CHAR : 
	seti_coffee = "\ue61b"
	# CHAR : 
	seti_coldfusion = "\ue645"
	# CHAR : 
	seti_config = "\ue615"
	# CHAR : 
	seti_cpp = "\ue646"
	# CHAR : 
	seti_crystal = "\ue62f"
	# CHAR : 
	seti_crystal_embedded = "\ue647"
	# CHAR : 
	seti_css = "\ue614"
	# CHAR : 
	seti_csv = "\ue64a"
	# CHAR : 
	seti_cu = "\ue64b"
	# CHAR : 
	seti_d = "\ue651"
	# CHAR : 
	seti_dart = "\ue64c"
	# CHAR : 
	seti_db = "\ue64d"
	# CHAR : 
	seti_default = "\ue64e"
	# CHAR : 
	seti_deprecation_cop = "\ue64f"
	# CHAR : 
	seti_docker = "\ue650"
	# CHAR : 
	seti_editorconfig = "\ue652"
	# CHAR : 
	seti_ejs = "\ue618"
	# CHAR : 
	seti_elixir = "\ue62d"
	# CHAR : 
	seti_elixir_script = "\ue653"
	# CHAR : 
	seti_elm = "\ue62c"
	# CHAR : 
	seti_error = "\ue654"
	# CHAR : 
	seti_eslint = "\ue655"
	# CHAR : 
	seti_ethereum = "\ue656"
	# CHAR : 
	seti_f_sharp = "\ue65a"
	# CHAR : 
	seti_favicon = "\ue623"
	# CHAR : 
	seti_firebase = "\ue657"
	# CHAR : 
	seti_firefox = "\ue658"
	# CHAR : 
	seti_folder = "\ue613"
	# CHAR : 
	seti_font = "\ue659"
	# CHAR : 
	seti_git = "\ue65d"
	# CHAR : 
	seti_git_folder = "\ue65d"
	# CHAR : 
	seti_git_ignore = "\ue65d"
	# CHAR : 
	seti_github = "\ue65b"
	# CHAR : 
	seti_gitlab = "\ue65c"
	# CHAR : 
	seti_go = "\ue627"
	# CHAR : 
	seti_go2 = "\ue65e"
	# CHAR : 
	seti_godot = "\ue65f"
	# CHAR : 
	seti_gradle = "\ue660"
	# CHAR : 
	seti_grails = "\ue661"
	# CHAR : 
	seti_graphql = "\ue662"
	# CHAR : 
	seti_grunt = "\ue611"
	# CHAR : 
	seti_gulp = "\ue610"
	# CHAR : 
	seti_hacklang = "\ue663"
	# CHAR : 
	seti_haml = "\ue664"
	# CHAR : 
	seti_happenings = "\ue665"
	# CHAR : 
	seti_haskell = "\ue61f"
	# CHAR : 
	seti_haxe = "\ue666"
	# CHAR : 
	seti_heroku = "\ue607"
	# CHAR : 
	seti_hex = "\ue667"
	# CHAR : 
	seti_home = "\ue617"
	# CHAR : 
	seti_html = "\ue60e"
	# CHAR : 
	seti_ignored = "\ue668"
	# CHAR : 
	seti_illustrator = "\ue669"
	# CHAR : 
	seti_image = "\ue60d"
	# CHAR : 
	seti_info = "\ue66a"
	# CHAR : 
	seti_ionic = "\ue66b"
	# CHAR : 
	seti_jade = "\ue66c"
	# CHAR : 
	seti_java = "\ue66d"
	# CHAR : 
	seti_javascript = "\ue60c"
	# CHAR : 
	seti_jenkins = "\ue66e"
	# CHAR : 
	seti_jinja = "\ue66f"
	# CHAR : 
	seti_json = "\ue60b"
	# CHAR : 
	seti_julia = "\ue624"
	# CHAR : 
	seti_karma = "\ue622"
	# CHAR : 
	seti_kotlin = "\ue634"
	# CHAR : 
	seti_less = "\ue60b"
	# CHAR : 
	seti_license = "\ue60a"
	# CHAR : 
	seti_liquid = "\ue670"
	# CHAR : 
	seti_livescript = "\ue671"
	# CHAR : 
	seti_lock = "\ue672"
	# CHAR : 
	seti_lua = "\ue620"
	# CHAR : 
	seti_makefile = "\ue673"
	# CHAR : 
	seti_markdown = "\ue609"
	# CHAR : 
	seti_maven = "\ue674"
	# CHAR : 
	seti_mdo = "\ue675"
	# CHAR : 
	seti_mustache = "\ue60f"
	# CHAR : 
	seti_new_file = "\ue676"
	# CHAR : 
	seti_nim = "\ue677"
	# CHAR : 
	seti_notebook = "\ue678"
	# CHAR : 
	seti_npm = "\ue616"
	# CHAR : 
	seti_npm_ignored = "\ue616"
	# CHAR : 
	seti_nunjucks = "\ue679"
	# CHAR : 
	seti_ocaml = "\ue67a"
	# CHAR : 
	seti_odata = "\ue67b"
	# CHAR : 
	seti_pddl = "\ue67c"
	# CHAR : 
	seti_pdf = "\ue67d"
	# CHAR : 
	seti_perl = "\ue67e"
	# CHAR : 
	seti_photoshop = "\ue67f"
	# CHAR : 
	seti_php = "\ue608"
	# CHAR : 
	seti_pipeline = "\ue680"
	# CHAR : 
	seti_plan = "\ue681"
	# CHAR : 
	seti_platformio = "\ue682"
	# CHAR : 
	seti_play_arrow = "\ue602"
	# CHAR : 
	seti_powershell = "\ue683"
	# CHAR : 
	seti_prisma = "\ue684"
	# CHAR : 
	seti_project = "\ue601"
	# CHAR : 
	seti_prolog = "\ue685"
	# CHAR : 
	seti_pug = "\ue686"
	# CHAR : 
	seti_puppet = "\ue631"
	# CHAR : 
	seti_purescript = "\ue630"
	# CHAR : 
	seti_python = "\ue606"
	# CHAR : 
	seti_r = "\ue68a"
	# CHAR : 
	seti_rails = "\ue604"
	# CHAR : 
	seti_react = "\ue625"
	# CHAR : 
	seti_reasonml = "\ue687"
	# CHAR : 
	seti_rescript = "\ue688"
	# CHAR : 
	seti_rollup = "\ue689"
	# CHAR : 
	seti_ruby = "\ue605"
	# CHAR : 
	seti_rust = "\ue68b"
	# CHAR : 
	seti_salesforce = "\ue68c"
	# CHAR : 
	seti_sass = "\ue603"
	# CHAR : 
	seti_sbt = "\ue68d"
	# CHAR : 
	seti_scala = "\ue68e"
	# CHAR : 
	seti_search = "\ue68f"
	# CHAR : 
	seti_settings = "\ue690"
	# CHAR : 
	seti_shell = "\ue691"
	# CHAR : 
	seti_slim = "\ue692"
	# CHAR : 
	seti_smarty = "\ue693"
	# CHAR : 
	seti_spring = "\ue694"
	# CHAR : 
	seti_stylelint = "\ue695"
	# CHAR : 
	seti_stylus = "\ue600"
	# CHAR : 
	seti_sublime = "\ue696"
	# CHAR : 
	seti_svelte = "\ue697"
	# CHAR : 
	seti_svg = "\ue698"
	# CHAR : 
	seti_swift = "\ue699"
	# CHAR : 
	seti_terraform = "\ue69a"
	# CHAR : 
	seti_tex = "\ue69b"
	# CHAR : 
	seti_text = "\ue64e"
	# CHAR : 
	seti_time_cop = "\ue641"
	# CHAR : 
	seti_todo = "\ue69c"
	# CHAR : 
	seti_tsconfig = "\ue69d"
	# CHAR : 
	seti_twig = "\ue61c"
	# CHAR : 
	seti_typescript = "\ue628"
	# CHAR : 
	seti_vala = "\ue69e"
	# CHAR : 
	seti_video = "\ue69f"
	# CHAR : 
	seti_vue = "\ue6a0"
	# CHAR : 
	seti_wasm = "\ue6a1"
	# CHAR : 
	seti_wat = "\ue6a2"
	# CHAR : 
	seti_webpack = "\ue6a3"
	# CHAR : 
	seti_wgt = "\ue6a4"
	# CHAR : 
	seti_word = "\ue6a5"
	# CHAR : 
	seti_xls = "\ue6a6"
	# CHAR : 
	seti_xml = "\ue619"
	# CHAR : 
	seti_yarn = "\ue6a7"
	# CHAR : 
	seti_yml = "\ue6a8"
	# CHAR : 
	seti_zig = "\ue6a9"
	# CHAR : 
	seti_zip = "\ue6aa"


# This File GEN using nerdicons_gen.py

class Ple:

	# CHAR : 
	ple_backslash_separator = "\ue0b9"
	# CHAR : 
	ple_backslash_separator_redundant = "\ue0bf"
	# CHAR : 
	ple_column_number = "\ue0a3"
	# CHAR : 
	ple_current_column = "\ue0a3"
	# CHAR : 
	ple_flame_thick = "\ue0c0"
	# CHAR : 
	ple_flame_thick_mirrored = "\ue0c2"
	# CHAR : 
	ple_flame_thin = "\ue0c1"
	# CHAR : 
	ple_flame_thin_mirrored = "\ue0c3"
	# CHAR : 
	ple_forwardslash_separator = "\ue0bb"
	# CHAR : 
	ple_forwardslash_separator_redundant = "\ue0bd"
	# CHAR : 
	ple_honeycomb = "\ue0cc"
	# CHAR : 
	ple_honeycomb_outline = "\ue0cd"
	# CHAR : 
	ple_ice_waveform = "\ue0c8"
	# CHAR : 
	ple_ice_waveform_mirrored = "\ue0ca"
	# CHAR : 
	ple_left_half_circle_thick = "\ue0b6"
	# CHAR : 
	ple_left_half_circle_thin = "\ue0b7"
	# CHAR : 
	ple_left_hard_divider_inverse = "\ue0d7"
	# CHAR : 
	ple_lego_block_facing = "\ue0d0"
	# CHAR : 
	ple_lego_block_sideways = "\ue0d1"
	# CHAR : 
	ple_lego_separator = "\ue0ce"
	# CHAR : 
	ple_lego_separator_thin = "\ue0cf"
	# CHAR : 
	ple_lower_left_triangle = "\ue0b8"
	# CHAR : 
	ple_lower_right_triangle = "\ue0ba"
	# CHAR : 
	ple_pixelated_squares_big = "\ue0c6"
	# CHAR : 
	ple_pixelated_squares_big_mirrored = "\ue0c7"
	# CHAR : 
	ple_pixelated_squares_small = "\ue0c4"
	# CHAR : 
	ple_pixelated_squares_small_mirrored = "\ue0c5"
	# CHAR : 
	ple_right_half_circle_thick = "\ue0b4"
	# CHAR : 
	ple_right_half_circle_thin = "\ue0b5"
	# CHAR : 
	ple_right_hard_divider_inverse = "\ue0d6"
	# CHAR : 
	ple_trapezoid_top_bottom = "\ue0d2"
	# CHAR : 
	ple_trapezoid_top_bottom_mirrored = "\ue0d4"
	# CHAR : 
	ple_upper_left_triangle = "\ue0bc"
	# CHAR : 
	ple_upper_right_triangle = "\ue0be"


# This File GEN using nerdicons_gen.py

class Pl:

	# CHAR : 
	pl_branch = "\ue0a0"
	# CHAR : 
	pl_current_line = "\ue0a1"
	# CHAR : 
	pl_hostname = "\ue0a2"
	# CHAR : 
	pl_left_hard_divider = "\ue0b0"
	# CHAR : 
	pl_left_soft_divider = "\ue0b1"
	# CHAR : 
	pl_line_number = "\ue0a1"
	# CHAR : 
	pl_readonly = "\ue0a2"
	# CHAR : 
	pl_right_hard_divider = "\ue0b2"
	# CHAR : 
	pl_right_soft_divider = "\ue0b3"


# This File GEN using nerdicons_gen.py

class Pom:

	# CHAR : 
	pom_away = "\ue007"
	# CHAR : 
	pom_clean_code = "\ue000"
	# CHAR : 
	pom_external_interruption = "\ue00a"
	# CHAR : 
	pom_internal_interruption = "\ue009"
	# CHAR : 
	pom_long_pause = "\ue006"
	# CHAR : 
	pom_pair_programming = "\ue008"
	# CHAR : 
	pom_pomodoro_done = "\ue001"
	# CHAR : 
	pom_pomodoro_estimated = "\ue002"
	# CHAR : 
	pom_pomodoro_squashed = "\ue004"
	# CHAR : 
	pom_pomodoro_ticking = "\ue003"
	# CHAR : 
	pom_short_pause = "\ue005"


# This File GEN using nerdicons_gen.py

class Oct:

	# CHAR : 
	oct_accessibility = "\uf406"
	# CHAR : 
	oct_accessibility_inset = "\uf40b"
	# CHAR : 
	oct_alert = "\uf421"
	# CHAR : 
	oct_alert_fill = "\uf40c"
	# CHAR : 
	oct_apps = "\uf40e"
	# CHAR : 
	oct_archive = "\uf411"
	# CHAR : 
	oct_arrow_both = "\uf416"
	# CHAR : 
	oct_arrow_down = "\uf433"
	# CHAR : 
	oct_arrow_down_left = "\uf424"
	# CHAR : 
	oct_arrow_down_right = "\uf43e"
	# CHAR : 
	oct_arrow_left = "\uf434"
	# CHAR : 
	oct_arrow_right = "\uf432"
	# CHAR : 
	oct_arrow_switch = "\uf443"
	# CHAR : 
	oct_arrow_up = "\uf431"
	# CHAR : 
	oct_arrow_up_left = "\uf45c"
	# CHAR : 
	oct_arrow_up_right = "\uf46c"
	# CHAR : 
	oct_beaker = "\uf499"
	# CHAR : 
	oct_bell = "\uf49a"
	# CHAR : 
	oct_bell_fill = "\uf476"
	# CHAR : 
	oct_bell_slash = "\uf478"
	# CHAR : 
	oct_blocked = "\uf479"
	# CHAR : 
	oct_bold = "\uf49d"
	# CHAR : 
	oct_book = "\uf405"
	# CHAR : 
	oct_bookmark = "\uf461"
	# CHAR : 
	oct_bookmark_fill = "\uf47a"
	# CHAR : 
	oct_bookmark_slash = "\uf533"
	# CHAR : 
	oct_bookmark_slash_fill = "\uf493"
	# CHAR : 
	oct_briefcase = "\uf491"
	# CHAR : 
	oct_broadcast = "\uf43c"
	# CHAR : 
	oct_browser = "\uf488"
	# CHAR : 
	oct_bug = "\uf46f"
	# CHAR : 
	oct_cache = "\uf49b"
	# CHAR : 
	oct_calendar = "\uf455"
	# CHAR : 
	oct_check = "\uf42e"
	# CHAR : 
	oct_check_circle = "\uf49e"
	# CHAR : 
	oct_check_circle_fill = "\uf4a4"
	# CHAR : 
	oct_checkbox = "\uf4a7"
	# CHAR : 
	oct_checklist = "\uf45e"
	# CHAR : 
	oct_chevron_down = "\uf47c"
	# CHAR : 
	oct_chevron_left = "\uf47d"
	# CHAR : 
	oct_chevron_right = "\uf460"
	# CHAR : 
	oct_chevron_up = "\uf47b"
	# CHAR : 
	oct_circle = "\uf4aa"
	# CHAR : 
	oct_circle_slash = "\uf468"
	# CHAR : 
	oct_clock = "\uf43a"
	# CHAR : 
	oct_clock_fill = "\uf4ab"
	# CHAR : 
	oct_cloud = "\uf4ac"
	# CHAR : 
	oct_cloud_offline = "\uf4ad"
	# CHAR : 
	oct_code = "\uf44f"
	# CHAR : 
	oct_code_of_conduct = "\uf4ae"
	# CHAR : 
	oct_code_review = "\uf4af"
	# CHAR : 
	oct_code_square = "\uf4b0"
	# CHAR : 
	oct_codescan = "\uf4b1"
	# CHAR : 
	oct_codescan_checkmark = "\uf4b2"
	# CHAR : 
	oct_codespaces = "\uf4b3"
	# CHAR : 
	oct_columns = "\uf4b4"
	# CHAR : 
	oct_command_palette = "\uf4b5"
	# CHAR : 
	oct_comment = "\uf41f"
	# CHAR : 
	oct_comment_discussion = "\uf442"
	# CHAR : 
	oct_commit = "\uf4b6"
	# CHAR : 
	oct_container = "\uf4b7"
	# CHAR : 
	oct_copilot = "\uf4b8"
	# CHAR : 
	oct_copilot_error = "\uf4b9"
	# CHAR : 
	oct_copilot_warning = "\uf4ba"
	# CHAR : 
	oct_copy = "\uf4bb"
	# CHAR : 
	oct_cpu = "\uf4bc"
	# CHAR : 
	oct_credit_card = "\uf439"
	# CHAR : 
	oct_cross_reference = "\uf4bd"
	# CHAR : 
	oct_dash = "\uf48b"
	# CHAR : 
	oct_database = "\uf472"
	# CHAR : 
	oct_dependabot = "\uf4be"
	# CHAR : 
	oct_desktop_download = "\uf498"
	# CHAR : 
	oct_device_camera = "\uf446"
	# CHAR : 
	oct_device_camera_video = "\uf447"
	# CHAR : 
	oct_device_desktop = "\uf4a9"
	# CHAR : 
	oct_device_mobile = "\uf42c"
	# CHAR : 
	oct_diamond = "\uf4bf"
	# CHAR : 
	oct_diff = "\uf440"
	# CHAR : 
	oct_diff_added = "\uf457"
	# CHAR : 
	oct_diff_ignored = "\uf474"
	# CHAR : 
	oct_diff_modified = "\uf459"
	# CHAR : 
	oct_diff_removed = "\uf458"
	# CHAR : 
	oct_diff_renamed = "\uf45a"
	# CHAR : 
	oct_discussion_closed = "\uf4c0"
	# CHAR : 
	oct_discussion_duplicate = "\uf4c1"
	# CHAR : 
	oct_discussion_outdated = "\uf4c2"
	# CHAR : 
	oct_dot = "\uf4c3"
	# CHAR : 
	oct_dot_fill = "\uf444"
	# CHAR : 
	oct_download = "\uf409"
	# CHAR : 
	oct_duplicate = "\uf4c4"
	# CHAR : 
	oct_ellipsis = "\uf475"
	# CHAR : 
	oct_eye = "\uf441"
	# CHAR : 
	oct_eye_closed = "\uf4c5"
	# CHAR : 
	oct_feed_discussion = "\uf4c6"
	# CHAR : 
	oct_feed_forked = "\uf4c7"
	# CHAR : 
	oct_feed_heart = "\uf4c8"
	# CHAR : 
	oct_feed_merged = "\uf4c9"
	# CHAR : 
	oct_feed_person = "\uf4ca"
	# CHAR : 
	oct_feed_repo = "\uf4cb"
	# CHAR : 
	oct_feed_rocket = "\uf4cc"
	# CHAR : 
	oct_feed_star = "\uf4cd"
	# CHAR : 
	oct_feed_tag = "\uf4ce"
	# CHAR : 
	oct_feed_trophy = "\uf4cf"
	# CHAR : 
	oct_file = "\uf4a5"
	# CHAR : 
	oct_file_added = "\uf4d0"
	# CHAR : 
	oct_file_badge = "\uf4d1"
	# CHAR : 
	oct_file_binary = "\uf471"
	# CHAR : 
	oct_file_code = "\uf40d"
	# CHAR : 
	oct_file_diff = "\uf4d2"
	# CHAR : 
	oct_file_directory = "\uf413"
	# CHAR : 
	oct_file_directory_fill = "\uf4d3"
	# CHAR : 
	oct_file_directory_open_fill = "\uf4d4"
	# CHAR : 
	oct_file_media = "\uf40f"
	# CHAR : 
	oct_file_moved = "\uf4d5"
	# CHAR : 
	oct_file_removed = "\uf4d6"
	# CHAR : 
	oct_file_submodule = "\uf414"
	# CHAR : 
	oct_file_symlink_directory = "\uf482"
	# CHAR : 
	oct_file_symlink_file = "\uf481"
	# CHAR : 
	oct_file_zip = "\uf410"
	# CHAR : 
	oct_filter = "\uf4d7"
	# CHAR : 
	oct_fiscal_host = "\uf4d8"
	# CHAR : 
	oct_flame = "\uf490"
	# CHAR : 
	oct_fold = "\uf48c"
	# CHAR : 
	oct_fold_down = "\uf4d9"
	# CHAR : 
	oct_fold_up = "\uf4da"
	# CHAR : 
	oct_gear = "\uf423"
	# CHAR : 
	oct_gift = "\uf436"
	# CHAR : 
	oct_git_branch = "\uf418"
	# CHAR : 
	oct_git_commit = "\uf417"
	# CHAR : 
	oct_git_compare = "\uf47f"
	# CHAR : 
	oct_git_merge = "\uf419"
	# CHAR : 
	oct_git_merge_queue = "\uf4db"
	# CHAR : 
	oct_git_pull_request = "\uf407"
	# CHAR : 
	oct_git_pull_request_closed = "\uf4dc"
	# CHAR : 
	oct_git_pull_request_draft = "\uf4dd"
	# CHAR : 
	oct_globe = "\uf484"
	# CHAR : 
	oct_goal = "\uf4de"
	# CHAR : 
	oct_grabber = "\uf4a6"
	# CHAR : 
	oct_graph = "\uf437"
	# CHAR : 
	oct_hash = "\uf4df"
	# CHAR : 
	oct_heading = "\uf4e0"
	# CHAR : ♥
	oct_heart = "\u2665"
	# CHAR : 
	oct_heart_fill = "\uf4e1"
	# CHAR : 
	oct_history = "\uf464"
	# CHAR : 
	oct_home = "\uf46d"
	# CHAR : 
	oct_home_fill = "\uf4e2"
	# CHAR : 
	oct_horizontal_rule = "\uf45b"
	# CHAR : 
	oct_hourglass = "\uf4e3"
	# CHAR : 
	oct_hubot = "\uf477"
	# CHAR : 
	oct_id_badge = "\uf4e4"
	# CHAR : 
	oct_image = "\uf4e5"
	# CHAR : 
	oct_inbox = "\uf48d"
	# CHAR : 
	oct_infinity = "\uf4e6"
	# CHAR : 
	oct_info = "\uf449"
	# CHAR : 
	oct_issue_closed = "\uf41d"
	# CHAR : 
	oct_issue_draft = "\uf4e7"
	# CHAR : 
	oct_issue_opened = "\uf41b"
	# CHAR : 
	oct_issue_reopened = "\uf41c"
	# CHAR : 
	oct_issue_tracked_by = "\uf4e8"
	# CHAR : 
	oct_issue_tracks = "\uf4e9"
	# CHAR : 
	oct_italic = "\uf49f"
	# CHAR : 
	oct_iterations = "\uf4ea"
	# CHAR : 
	oct_kebab_horizontal = "\uf4eb"
	# CHAR : 
	oct_key = "\uf43d"
	# CHAR : 
	oct_key_asterisk = "\uf4ec"
	# CHAR : 
	oct_law = "\uf495"
	# CHAR : 
	oct_light_bulb = "\uf400"
	# CHAR : 
	oct_link = "\uf44c"
	# CHAR : 
	oct_link_external = "\uf465"
	# CHAR : 
	oct_list_ordered = "\uf452"
	# CHAR : 
	oct_list_unordered = "\uf451"
	# CHAR : 
	oct_location = "\uf450"
	# CHAR : 
	oct_lock = "\uf456"
	# CHAR : 
	oct_log = "\uf4ed"
	# CHAR : 
	oct_logo_gist = "\uf480"
	# CHAR : 
	oct_logo_github = "\uf470"
	# CHAR : 
	oct_mail = "\uf42f"
	# CHAR : 
	oct_mark_github = "\uf408"
	# CHAR : 
	oct_markdown = "\uf48a"
	# CHAR : 
	oct_megaphone = "\uf45f"
	# CHAR : 
	oct_mention = "\uf486"
	# CHAR : 
	oct_meter = "\uf463"
	# CHAR : 
	oct_milestone = "\uf45d"
	# CHAR : 
	oct_mirror = "\uf41a"
	# CHAR : 
	oct_moon = "\uf4ee"
	# CHAR : 
	oct_mortar_board = "\uf494"
	# CHAR : 
	oct_move_to_bottom = "\uf4ef"
	# CHAR : 
	oct_move_to_end = "\uf4f0"
	# CHAR : 
	oct_move_to_start = "\uf4f1"
	# CHAR : 
	oct_move_to_top = "\uf4f2"
	# CHAR : 
	oct_multi_select = "\uf4f3"
	# CHAR : 
	oct_mute = "\uf466"
	# CHAR : 
	oct_no_entry = "\uf4f4"
	# CHAR : 
	oct_north_star = "\uf4f5"
	# CHAR : 
	oct_note = "\uf4f6"
	# CHAR : 
	oct_number = "\uf4f7"
	# CHAR : 
	oct_organization = "\uf42b"
	# CHAR : 
	oct_package = "\uf487"
	# CHAR : 
	oct_package_dependencies = "\uf4f8"
	# CHAR : 
	oct_package_dependents = "\uf4f9"
	# CHAR : 
	oct_paintbrush = "\uf48f"
	# CHAR : 
	oct_paper_airplane = "\uf4fa"
	# CHAR : 
	oct_paperclip = "\uf4fb"
	# CHAR : 
	oct_passkey_fill = "\uf4fc"
	# CHAR : 
	oct_paste = "\uf429"
	# CHAR : 
	oct_pencil = "\uf448"
	# CHAR : 
	oct_people = "\uf4fd"
	# CHAR : 
	oct_person = "\uf415"
	# CHAR : 
	oct_person_add = "\uf4fe"
	# CHAR : 
	oct_person_fill = "\uf4ff"
	# CHAR : 
	oct_pin = "\uf435"
	# CHAR : 
	oct_play = "\uf500"
	# CHAR : 
	oct_plug = "\uf492"
	# CHAR : 
	oct_plus = "\uf44d"
	# CHAR : 
	oct_plus_circle = "\uf501"
	# CHAR : 
	oct_project = "\uf502"
	# CHAR : 
	oct_project_roadmap = "\uf503"
	# CHAR : 
	oct_project_symlink = "\uf504"
	# CHAR : 
	oct_project_template = "\uf505"
	# CHAR : 
	oct_pulse = "\uf469"
	# CHAR : 
	oct_question = "\uf420"
	# CHAR : 
	oct_quote = "\uf453"
	# CHAR : 
	oct_read = "\uf430"
	# CHAR : 
	oct_rel_file_path = "\uf506"
	# CHAR : 
	oct_reply = "\uf4a8"
	# CHAR : 
	oct_repo = "\uf401"
	# CHAR : 
	oct_repo_clone = "\uf43f"
	# CHAR : 
	oct_repo_deleted = "\uf507"
	# CHAR : 
	oct_repo_forked = "\uf402"
	# CHAR : 
	oct_repo_locked = "\uf508"
	# CHAR : 
	oct_repo_pull = "\uf404"
	# CHAR : 
	oct_repo_push = "\uf403"
	# CHAR : 
	oct_repo_template = "\uf509"
	# CHAR : 
	oct_report = "\uf50a"
	# CHAR : 
	oct_rocket = "\uf427"
	# CHAR : 
	oct_rows = "\uf50b"
	# CHAR : 
	oct_rss = "\uf428"
	# CHAR : 
	oct_ruby = "\uf43b"
	# CHAR : 
	oct_screen_full = "\uf50c"
	# CHAR : 
	oct_screen_normal = "\uf50d"
	# CHAR : 
	oct_search = "\uf422"
	# CHAR : 
	oct_server = "\uf473"
	# CHAR : 
	oct_share = "\uf50e"
	# CHAR : 
	oct_share_android = "\uf50f"
	# CHAR : 
	oct_shield = "\uf49c"
	# CHAR : 
	oct_shield_check = "\uf510"
	# CHAR : 
	oct_shield_lock = "\uf511"
	# CHAR : 
	oct_shield_slash = "\uf512"
	# CHAR : 
	oct_shield_x = "\uf513"
	# CHAR : 
	oct_sidebar_collapse = "\uf514"
	# CHAR : 
	oct_sidebar_expand = "\uf515"
	# CHAR : 
	oct_sign_in = "\uf42a"
	# CHAR : 
	oct_sign_out = "\uf426"
	# CHAR : 
	oct_single_select = "\uf516"
	# CHAR : 
	oct_skip = "\uf517"
	# CHAR : 
	oct_skip_fill = "\uf518"
	# CHAR : 
	oct_sliders = "\uf462"
	# CHAR : 
	oct_smiley = "\uf4a2"
	# CHAR : 
	oct_sort_asc = "\uf519"
	# CHAR : 
	oct_sort_desc = "\uf51a"
	# CHAR : 
	oct_sparkle_fill = "\uf51b"
	# CHAR : 
	oct_sponsor_tiers = "\uf51c"
	# CHAR : 
	oct_square = "\uf51d"
	# CHAR : 
	oct_square_fill = "\uf445"
	# CHAR : 
	oct_squirrel = "\uf483"
	# CHAR : 
	oct_stack = "\uf51e"
	# CHAR : 
	oct_star = "\uf41e"
	# CHAR : 
	oct_star_fill = "\uf51f"
	# CHAR : 
	oct_stop = "\uf46e"
	# CHAR : 
	oct_stopwatch = "\uf520"
	# CHAR : 
	oct_strikethrough = "\uf521"
	# CHAR : 
	oct_sun = "\uf522"
	# CHAR : 
	oct_sync = "\uf46a"
	# CHAR : 
	oct_tab = "\uf523"
	# CHAR : 
	oct_tab_external = "\uf524"
	# CHAR : 
	oct_table = "\uf525"
	# CHAR : 
	oct_tag = "\uf412"
	# CHAR : 
	oct_tasklist = "\uf4a0"
	# CHAR : 
	oct_telescope = "\uf46b"
	# CHAR : 
	oct_telescope_fill = "\uf526"
	# CHAR : 
	oct_terminal = "\uf489"
	# CHAR : 
	oct_three_bars = "\uf44e"
	# CHAR : 
	oct_thumbsdown = "\uf497"
	# CHAR : 
	oct_thumbsup = "\uf496"
	# CHAR : 
	oct_tools = "\uf425"
	# CHAR : 
	oct_trash = "\uf48e"
	# CHAR : 
	oct_triangle_down = "\uf44b"
	# CHAR : 
	oct_triangle_left = "\uf438"
	# CHAR : 
	oct_triangle_right = "\uf44a"
	# CHAR : 
	oct_triangle_up = "\uf47e"
	# CHAR : 
	oct_trophy = "\uf527"
	# CHAR : 
	oct_typography = "\uf528"
	# CHAR : 
	oct_unfold = "\uf42d"
	# CHAR : 
	oct_unlink = "\uf529"
	# CHAR : 
	oct_unlock = "\uf52a"
	# CHAR : 
	oct_unmute = "\uf485"
	# CHAR : 
	oct_unread = "\uf52b"
	# CHAR : 
	oct_unverified = "\uf4a3"
	# CHAR : 
	oct_upload = "\uf40a"
	# CHAR : 
	oct_verified = "\uf4a1"
	# CHAR : 
	oct_versions = "\uf454"
	# CHAR : 
	oct_video = "\uf52c"
	# CHAR : 
	oct_webhook = "\uf52d"
	# CHAR : 
	oct_workflow = "\uf52e"
	# CHAR : 
	oct_x = "\uf467"
	# CHAR : 
	oct_x_circle = "\uf52f"
	# CHAR : 
	oct_x_circle_fill = "\uf530"
	# CHAR : ⚡
	oct_zap = "\u26a1"
	# CHAR : 
	oct_zoom_in = "\uf531"
	# CHAR : 
	oct_zoom_out = "\uf532"


# This File GEN using nerdicons_gen.py

class Custom:

	# CHAR : 
	custom_ada = "\ue6b5"
	# CHAR : 
	custom_asm = "\ue6ab"
	# CHAR : 
	custom_astro = "\ue6b3"
	# CHAR : 
	custom_bazel = "\ue63a"
	# CHAR : 
	custom_c = "\ue61e"
	# CHAR : 
	custom_chuck = "\ue6b6"
	# CHAR : 
	custom_common_lisp = "\ue6b0"
	# CHAR : 
	custom_cpp = "\ue61d"
	# CHAR : 
	custom_crystal = "\ue62f"
	# CHAR : 
	custom_css = "\ue6b8"
	# CHAR : 
	custom_default = "\ue612"
	# CHAR : 
	custom_electron = "\ue62e"
	# CHAR : 
	custom_elixir = "\ue62d"
	# CHAR : 
	custom_elm = "\ue62c"
	# CHAR : 
	custom_emacs = "\ue632"
	# CHAR : 
	custom_fennel = "\ue6af"
	# CHAR : 
	custom_firebase = "\ue657"
	# CHAR : 
	custom_folder = "\ue5ff"
	# CHAR : 
	custom_folder_config = "\ue5fc"
	# CHAR : 
	custom_folder_git = "\ue5fb"
	# CHAR : 
	custom_folder_git_branch = "\ue5fb"
	# CHAR : 
	custom_folder_github = "\ue5fd"
	# CHAR : 
	custom_folder_npm = "\ue5fa"
	# CHAR : 
	custom_folder_oct = "\ue6ad"
	# CHAR : 
	custom_folder_open = "\ue5fe"
	# CHAR : 
	custom_go = "\ue626"
	# CHAR : 
	custom_home = "\ue617"
	# CHAR : 
	custom_kotlin = "\ue634"
	# CHAR : 
	custom_msdos = "\ue629"
	# CHAR : 
	custom_neovim = "\ue6ae"
	# CHAR : 
	custom_orgmode = "\ue633"
	# CHAR : 
	custom_play_arrow = "\ue602"
	# CHAR : 
	custom_prettier = "\ue6b4"
	# CHAR : 
	custom_puppet = "\ue631"
	# CHAR : 
	custom_purescript = "\ue630"
	# CHAR : 
	custom_ruby = "\ue605"
	# CHAR : 
	custom_scheme = "\ue6b1"
	# CHAR : 
	custom_toml = "\ue6b2"
	# CHAR : 
	custom_v_lang = "\ue6ac"
	# CHAR : 
	custom_vim = "\ue62b"
	# CHAR : 
	custom_vitruvian = "\ue6b7"
	# CHAR : 
	custom_windows = "\ue62a"